@@ -98,10 +98,9 @@
 #'          Use \code{"l"} for upper left corner.
 #' @param axis.titles character vector of length one or two, defining the title(s)
 #'          for the x-axis and y-axis.
-#' @param drop.empty Logical, if \code{TRUE} and the variable's values are labeled,
-#'          values that have no observations are still printed in the table (with
-#'          frequency \code{0}). If \code{FALSE}, values / factor levels with no occurrence
-#'          in the data are omitted from the output.
+#' @param drop.empty Logical, if \code{TRUE} and the variable's values are labeled, values / factor
+#'          levels with no occurrence in the data are omitted from the output. If \code{FALSE},
+#'          labeled values that have no observations are still printed in the table (with frequency \code{0}).
 #' @param auto.group numeric value, indicating the minimum amount of unique values
 #'          in the count variable, at which automatic grouping into smaller units
 #'          is done (see \code{\link[sjmisc]{group_var}}). Default value for
@@ -133,7 +132,7 @@
 #'            \item If not specified, a default color brewer palette will be used, which is suitable for the plot style (i.e. diverging for likert scales, qualitative for grouped bars etc.).
 #'            \item If \code{"gs"}, a greyscale will be used.
 #'            \item If \code{"bw"}, and plot-type is a line-plot, the plot is black/white and uses different line types to distinguish groups (see \href{https://strengejacke.github.io/sjPlot/articles/blackwhitefigures.html}{this package-vignette}).
-#'            \item If \code{geom.colors} is any valid color brewer palette name, the related palette will be used. Use \code{\link[RColorBrewer]{display.brewer.all}} to view all available palette names.
+#'            \item If \code{geom.colors} is any valid color brewer palette name, the related palette will be used. Use \code{RColorBrewer::display.brewer.all()} to view all available palette names.
 #'            \item Else specify own color values or names as vector (e.g. \code{geom.colors = c("#f00000", "#00ff00")}).
 #'          }
 #'
@@ -165,10 +164,6 @@
 #' plot_grpfrq(efc$c161sex, efc$e42dep, drop.empty = FALSE)
 #'
 #' @import ggplot2
-#' @importFrom sjstats weight2
-#' @importFrom tidyr gather
-#' @importFrom dplyr group_by mutate arrange summarise
-#' @importFrom stats na.omit xtabs wilcox.test sd
 #' @importFrom rlang .data
 #' @export
 plot_grpfrq <- function(var.cnt,
@@ -654,9 +649,9 @@ plot_grpfrq <- function(var.cnt,
       geob <- geom_bar(stat = "identity", width = geom.size, position = position_stack(reverse = TRUE))
   } else if (type == "line") {
     if (smooth.lines)
-      geob <- geom_line(size = geom.size, stat = "smooth", method = "loess")
+      geob <- geom_line(linewidth = geom.size, stat = "smooth", method = "loess")
     else
-      geob <- geom_line(size = geom.size)
+      geob <- geom_line(linewidth = geom.size)
   } else if (type == "boxplot") {
       geob <- geom_boxplot(width = geom.size, notch = show.ci)
   } else if (type == "violin") {
